diff --git a/.github/workflows/build-docker.yml b/.github/workflows/build-docker.yml
index cf9f3fe87..08b3739cc 100644
--- a/.github/workflows/build-docker.yml
+++ b/.github/workflows/build-docker.yml
@@ -48,7 +48,7 @@ jobs:
REACT_APP_BUILD
REACT_APP_BUILD_TIME
push: ${{ env.push }}
- tags: ghcr.io/c4dt/d-voting-frontend:${{ env.DockerTag }}
+ tags: ghcr.io/dedis/d-voting-frontend:${{ env.DockerTag }}
- name: Build Backend
uses: docker/build-push-action@v2
with:
@@ -56,7 +56,7 @@ jobs:
file: Dockerfiles/Dockerfile.backend
platforms: linux/amd64
push: ${{ env.push }}
- tags: ghcr.io/c4dt/d-voting-backend:${{ env.DockerTag }}
+ tags: ghcr.io/dedis/d-voting-backend:${{ env.DockerTag }}
- name: Build D-Voting
uses: docker/build-push-action@v2
with:
@@ -64,4 +64,4 @@ jobs:
file: Dockerfiles/Dockerfile.dela
platforms: linux/amd64
push: ${{ env.push }}
- tags: ghcr.io/c4dt/d-voting-dela:${{ env.DockerTag }}
+ tags: ghcr.io/dedis/d-voting-dela:${{ env.DockerTag }}
diff --git a/.github/workflows/go_dvoting_test.yml b/.github/workflows/go_dvoting_test.yml
index 19acabb77..f82bdbd53 100644
--- a/.github/workflows/go_dvoting_test.yml
+++ b/.github/workflows/go_dvoting_test.yml
@@ -19,7 +19,7 @@ jobs:
- name: Install crypto util from Dela
run: |
- git clone https://github.com/c4dt/dela.git
+ git clone https://github.com/dedis/dela.git
cd dela
go install ./cli/crypto
diff --git a/.github/workflows/go_scenario_test.yml b/.github/workflows/go_scenario_test.yml
index c6f274417..54027938f 100644
--- a/.github/workflows/go_scenario_test.yml
+++ b/.github/workflows/go_scenario_test.yml
@@ -18,7 +18,7 @@ jobs:
- name: Install crypto util from Dela
run: |
- git clone https://github.com/c4dt/dela.git
+ git clone https://github.com/dedis/dela.git
cd dela
go install ./cli/crypto
diff --git a/.github/workflows/go_test.yml b/.github/workflows/go_test.yml
index 302364b03..821477592 100644
--- a/.github/workflows/go_test.yml
+++ b/.github/workflows/go_test.yml
@@ -19,9 +19,10 @@ jobs:
- name: Check out code into the Go module directory
uses: actions/checkout@v3
- - name: Run lint
- run: make lint
-
+# TODO: https://github.com/dedis/d-voting/issues/392
+# - name: Run lint
+# run: make lint
+#
- name: Run vet
run: make vet
diff --git a/Makefile b/Makefile
index a7eb71f25..a774d69a0 100644
--- a/Makefile
+++ b/Makefile
@@ -1,7 +1,7 @@
version=$(shell git describe --abbrev=0 --tags || echo '0.0.0')
-versionFlag="github.com/c4dt/d-voting.Version=$(version)"
+versionFlag="github.com/dedis/d-voting.Version=$(version)"
versionFile=$(shell echo $(version) | tr . _)
-timeFlag="github.com/c4dt/d-voting.BuildTime=$(shell date +'%d/%m/%y_%H:%M')"
+timeFlag="github.com/dedis/d-voting.BuildTime=$(shell date +'%d/%m/%y_%H:%M')"
lint:
# Coding style static check.
diff --git a/README.md b/README.md
index 0daa94363..cf4c87cc7 100644
--- a/README.md
+++ b/README.md
@@ -12,13 +12,13 @@
-
-
+
+
-
+
-
+
@@ -26,37 +26,37 @@
Blockchain |
-
-
+
+
-
-
+
+
-
-
+
+
-
-
+
+
-
-
+
+
-
-
+
+
|
WEB |
-
-
+
+
-
-
+
+
|
@@ -67,7 +67,7 @@
# D-Voting
**D-Voting** is an e-voting platform based on the
-[Dela](https://github.com/c4dt/dela) blockchain. It uses state-of-the-art
+[Dela](https://github.com/dedis/dela) blockchain. It uses state-of-the-art
protocols that guarantee privacy of votes and a fully decentralized process.
This project was born in early 2021 and has been iteratively implemented by EPFL
students under the supervision of DEDIS members.
@@ -147,7 +147,7 @@ sometimes refer to the blockchain node simply as a "node".
The following component diagrams summarizes the interaction between those
high-level components:
-[minogrpc]: https://github.com/c4dt/dela/tree/master/mino/minogrpc
+[minogrpc]: https://github.com/dedis/dela/tree/master/mino/minogrpc
![Global component diagram](http://www.plantuml.com/plantuml/proxy?src=https://raw.githubusercontent.com/dedis/d-voting/main/docs/assets/component-global.puml)
@@ -390,7 +390,7 @@ results.
2: Install the `crypto` utility from Dela:
```sh
-git clone https://github.com/c4dt/dela.git
+git clone https://github.com/dedis/dela.git
cd dela/cli/crypto
go install
```
@@ -601,7 +601,7 @@ Afterwards use the following commands, replace 4 by the desired nb of nodes :
./runNode.sh -n 4 -a true -d true
./setupnNode.sh -n 4 -d true
-NNODES=4 KILLNODE=true go test -v -run ^TestScenario$ github.com/c4dt/d-voting/integration -count=1
+NNODES=4 KILLNODE=true go test -v -run ^TestScenario$ github.com/dedis/d-voting/integration -count=1
```
Here we set KILLNODE=true or false to decide whether kill and restart a node
@@ -650,8 +650,8 @@ Build info can be added to the binary with the `ldflags`, at build time. Infos
are stored on variables in the root `mod.go`. For example:
```sh
-versionFlag="github.com/c4dt/d-voting.Version=`git describe --tags`"
-timeFlag="github.com/c4dt/d-voting.BuildTime=`date +'%d/%m/%y_%H:%M'`"
+versionFlag="github.com/dedis/d-voting.Version=`git describe --tags`"
+timeFlag="github.com/dedis/d-voting.BuildTime=`date +'%d/%m/%y_%H:%M'`"
go build -ldflags="-X $versionFlag -X $timeFlag" ./cli/dvoting
```
diff --git a/autotest.sh b/autotest.sh
index 67ef14ec1..b9872287b 100755
--- a/autotest.sh
+++ b/autotest.sh
@@ -52,7 +52,7 @@ do
./setupnNode.sh -n $N_NODE -d true
sleep 3
# Start scenario test and keep logs
- NNODES=$N_NODE go test -v -run ^TestScenario$ github.com/c4dt/d-voting/integration -count=1 | tee ./log/log/gotest.log
+ NNODES=$N_NODE go test -v -run ^TestScenario$ github.com/dedis/d-voting/integration -count=1 | tee ./log/log/gotest.log
sleep 3
# Stop the test
./kill_test.sh
diff --git a/cli/cosipbftcontroller/action_test.go b/cli/cosipbftcontroller/action_test.go
index 20f9b475f..2d0ba484c 100644
--- a/cli/cosipbftcontroller/action_test.go
+++ b/cli/cosipbftcontroller/action_test.go
@@ -7,7 +7,7 @@ import (
"testing"
"time"
- "github.com/c4dt/d-voting/internal/testing/fake"
+ "github.com/dedis/d-voting/internal/testing/fake"
"github.com/stretchr/testify/require"
"go.dedis.ch/dela/cli/node"
"go.dedis.ch/dela/core/access"
diff --git a/cli/cosipbftcontroller/mod_test.go b/cli/cosipbftcontroller/mod_test.go
index 5f29fedb1..ac9e3525e 100644
--- a/cli/cosipbftcontroller/mod_test.go
+++ b/cli/cosipbftcontroller/mod_test.go
@@ -6,10 +6,10 @@ import (
"path/filepath"
"testing"
- "github.com/c4dt/d-voting/services/dkg"
+ "github.com/dedis/d-voting/services/dkg"
"go.dedis.ch/dela/core/ordering"
- "github.com/c4dt/d-voting/internal/testing/fake"
+ "github.com/dedis/d-voting/internal/testing/fake"
"github.com/stretchr/testify/require"
"go.dedis.ch/dela/cli"
"go.dedis.ch/dela/cli/node"
diff --git a/cli/dvoting/mod.go b/cli/dvoting/mod.go
index a378a12c5..f562ed5bf 100644
--- a/cli/dvoting/mod.go
+++ b/cli/dvoting/mod.go
@@ -30,14 +30,14 @@ import (
"io"
"os"
- dkg "github.com/c4dt/d-voting/services/dkg/pedersen/controller"
- "github.com/c4dt/d-voting/services/dkg/pedersen/json"
- shuffle "github.com/c4dt/d-voting/services/shuffle/neff/controller"
+ dkg "github.com/dedis/d-voting/services/dkg/pedersen/controller"
+ "github.com/dedis/d-voting/services/dkg/pedersen/json"
+ shuffle "github.com/dedis/d-voting/services/shuffle/neff/controller"
- cosipbft "github.com/c4dt/d-voting/cli/cosipbftcontroller"
- "github.com/c4dt/d-voting/cli/postinstall"
- evoting "github.com/c4dt/d-voting/contracts/evoting/controller"
- metrics "github.com/c4dt/d-voting/metrics/controller"
+ cosipbft "github.com/dedis/d-voting/cli/cosipbftcontroller"
+ "github.com/dedis/d-voting/cli/postinstall"
+ evoting "github.com/dedis/d-voting/contracts/evoting/controller"
+ metrics "github.com/dedis/d-voting/metrics/controller"
"go.dedis.ch/dela/cli/node"
access "go.dedis.ch/dela/contracts/access/controller"
db "go.dedis.ch/dela/core/store/kv/controller"
@@ -46,7 +46,7 @@ import (
mino "go.dedis.ch/dela/mino/minogrpc/controller"
proxy "go.dedis.ch/dela/mino/proxy/http/controller"
- _ "github.com/c4dt/d-voting/services/shuffle/neff/json"
+ _ "github.com/dedis/d-voting/services/shuffle/neff/json"
gapi "go.dedis.ch/dela-apps/gapi/controller"
)
diff --git a/cli/postinstall/mod.go b/cli/postinstall/mod.go
index 1c3e8ccf3..560e57d40 100644
--- a/cli/postinstall/mod.go
+++ b/cli/postinstall/mod.go
@@ -5,10 +5,10 @@ import (
"path/filepath"
"time"
- evoting "github.com/c4dt/d-voting/contracts/evoting/controller"
- prom "github.com/c4dt/d-voting/metrics/controller"
- dkg "github.com/c4dt/d-voting/services/dkg/pedersen/controller"
- neff "github.com/c4dt/d-voting/services/shuffle/neff/controller"
+ evoting "github.com/dedis/d-voting/contracts/evoting/controller"
+ prom "github.com/dedis/d-voting/metrics/controller"
+ dkg "github.com/dedis/d-voting/services/dkg/pedersen/controller"
+ neff "github.com/dedis/d-voting/services/shuffle/neff/controller"
"go.dedis.ch/dela"
"go.dedis.ch/dela/cli"
"go.dedis.ch/dela/cli/node"
diff --git a/contracts/evoting/controller/action.go b/contracts/evoting/controller/action.go
index 1b674e716..7073e16c9 100644
--- a/contracts/evoting/controller/action.go
+++ b/contracts/evoting/controller/action.go
@@ -17,13 +17,13 @@ import (
"go.dedis.ch/kyber/v3/sign/schnorr"
"go.dedis.ch/kyber/v3/suites"
- "github.com/c4dt/d-voting/contracts/evoting/types"
- "github.com/c4dt/d-voting/internal/testing/fake"
- eproxy "github.com/c4dt/d-voting/proxy"
- "github.com/c4dt/d-voting/proxy/txnmanager"
- ptypes "github.com/c4dt/d-voting/proxy/types"
- "github.com/c4dt/d-voting/services/dkg"
- "github.com/c4dt/d-voting/services/shuffle"
+ "github.com/dedis/d-voting/contracts/evoting/types"
+ "github.com/dedis/d-voting/internal/testing/fake"
+ eproxy "github.com/dedis/d-voting/proxy"
+ "github.com/dedis/d-voting/proxy/txnmanager"
+ ptypes "github.com/dedis/d-voting/proxy/types"
+ "github.com/dedis/d-voting/services/dkg"
+ "github.com/dedis/d-voting/services/shuffle"
"github.com/gorilla/mux"
"go.dedis.ch/dela"
"go.dedis.ch/dela/cli/node"
diff --git a/contracts/evoting/evoting.go b/contracts/evoting/evoting.go
index 082597c31..03e7e4cc7 100644
--- a/contracts/evoting/evoting.go
+++ b/contracts/evoting/evoting.go
@@ -15,7 +15,7 @@ import (
"go.dedis.ch/dela/core/ordering/cosipbft/contracts/viewchange"
"go.dedis.ch/kyber/v3/share"
- "github.com/c4dt/d-voting/contracts/evoting/types"
+ "github.com/dedis/d-voting/contracts/evoting/types"
"go.dedis.ch/dela/core/execution"
"go.dedis.ch/dela/core/execution/native"
"go.dedis.ch/dela/core/ordering/cosipbft/authority"
diff --git a/contracts/evoting/json/ciphervote.go b/contracts/evoting/json/ciphervote.go
index 2c9032b5c..b8c51b65d 100644
--- a/contracts/evoting/json/ciphervote.go
+++ b/contracts/evoting/json/ciphervote.go
@@ -1,7 +1,7 @@
package json
import (
- "github.com/c4dt/d-voting/contracts/evoting/types"
+ "github.com/dedis/d-voting/contracts/evoting/types"
"go.dedis.ch/dela/serde"
"golang.org/x/xerrors"
)
diff --git a/contracts/evoting/json/forms.go b/contracts/evoting/json/forms.go
index 2640cfd80..63f05b9ef 100644
--- a/contracts/evoting/json/forms.go
+++ b/contracts/evoting/json/forms.go
@@ -4,7 +4,7 @@ import (
"encoding/hex"
"encoding/json"
- "github.com/c4dt/d-voting/contracts/evoting/types"
+ "github.com/dedis/d-voting/contracts/evoting/types"
"go.dedis.ch/dela/core/ordering/cosipbft/authority"
ctypes "go.dedis.ch/dela/core/ordering/cosipbft/types"
"go.dedis.ch/dela/serde"
@@ -36,8 +36,8 @@ func (formFormat) Encode(ctx serde.Context, message serde.Message) ([]byte, erro
}
}
- suffragias := make([]string, len(m.SuffragiaIDs))
- for i, suf := range m.SuffragiaIDs {
+ suffragias := make([]string, len(m.SuffragiaStoreKeys))
+ for i, suf := range m.SuffragiaStoreKeys {
suffragias[i] = hex.EncodeToString(suf)
}
@@ -146,19 +146,19 @@ func (formFormat) Decode(ctx serde.Context, data []byte) (serde.Message, error)
}
return types.Form{
- Configuration: formJSON.Configuration,
- FormID: formJSON.FormID,
- Status: types.Status(formJSON.Status),
- Pubkey: pubKey,
- BallotSize: formJSON.BallotSize,
- SuffragiaIDs: suffragias,
- SuffragiaHashes: suffragiaHashes,
- BallotCount: formJSON.BallotCount,
- ShuffleInstances: shuffleInstances,
- ShuffleThreshold: formJSON.ShuffleThreshold,
- PubsharesUnits: pubSharesSubmissions,
- DecryptedBallots: formJSON.DecryptedBallots,
- Roster: roster,
+ Configuration: formJSON.Configuration,
+ FormID: formJSON.FormID,
+ Status: types.Status(formJSON.Status),
+ Pubkey: pubKey,
+ BallotSize: formJSON.BallotSize,
+ SuffragiaStoreKeys: suffragias,
+ SuffragiaHashes: suffragiaHashes,
+ BallotCount: formJSON.BallotCount,
+ ShuffleInstances: shuffleInstances,
+ ShuffleThreshold: formJSON.ShuffleThreshold,
+ PubsharesUnits: pubSharesSubmissions,
+ DecryptedBallots: formJSON.DecryptedBallots,
+ Roster: roster,
}, nil
}
diff --git a/contracts/evoting/json/mod.go b/contracts/evoting/json/mod.go
index c9845338a..5906611ce 100644
--- a/contracts/evoting/json/mod.go
+++ b/contracts/evoting/json/mod.go
@@ -1,7 +1,7 @@
package json
import (
- "github.com/c4dt/d-voting/contracts/evoting/types"
+ "github.com/dedis/d-voting/contracts/evoting/types"
"go.dedis.ch/dela/serde"
)
diff --git a/contracts/evoting/json/suffragia.go b/contracts/evoting/json/suffragia.go
index 424c83910..7510f18bb 100644
--- a/contracts/evoting/json/suffragia.go
+++ b/contracts/evoting/json/suffragia.go
@@ -3,7 +3,7 @@ package json
import (
"encoding/json"
- "github.com/c4dt/d-voting/contracts/evoting/types"
+ "github.com/dedis/d-voting/contracts/evoting/types"
"go.dedis.ch/dela/serde"
"golang.org/x/xerrors"
)
diff --git a/contracts/evoting/json/transaction.go b/contracts/evoting/json/transaction.go
index 1093416df..6bbe77a98 100644
--- a/contracts/evoting/json/transaction.go
+++ b/contracts/evoting/json/transaction.go
@@ -3,7 +3,7 @@ package json
import (
"encoding/json"
- "github.com/c4dt/d-voting/contracts/evoting/types"
+ "github.com/dedis/d-voting/contracts/evoting/types"
"go.dedis.ch/dela/serde"
"golang.org/x/xerrors"
)
diff --git a/contracts/evoting/mod.go b/contracts/evoting/mod.go
index b431bc445..544269deb 100644
--- a/contracts/evoting/mod.go
+++ b/contracts/evoting/mod.go
@@ -1,15 +1,16 @@
package evoting
import (
- dvoting "github.com/c4dt/d-voting"
- "github.com/c4dt/d-voting/contracts/evoting/types"
- "github.com/c4dt/d-voting/services/dkg"
+ dvoting "github.com/dedis/d-voting"
+ "github.com/dedis/d-voting/contracts/evoting/types"
+ "github.com/dedis/d-voting/services/dkg"
"github.com/prometheus/client_golang/prometheus"
"go.dedis.ch/dela/core/access"
"go.dedis.ch/dela/core/execution"
"go.dedis.ch/dela/core/execution/native"
"go.dedis.ch/dela/core/ordering/cosipbft/authority"
"go.dedis.ch/dela/core/store"
+ "go.dedis.ch/dela/core/store/prefixed"
"go.dedis.ch/dela/serde"
"go.dedis.ch/dela/serde/json"
@@ -18,7 +19,7 @@ import (
"golang.org/x/xerrors"
// Register the JSON format for the form
- _ "github.com/c4dt/d-voting/contracts/evoting/json"
+ _ "github.com/dedis/d-voting/contracts/evoting/json"
)
var (
@@ -198,6 +199,8 @@ func (c Contract) Execute(snap store.Snapshot, step execution.Step) error {
return xerrors.Errorf("%q not found in tx arg", CmdArg)
}
+ snap = prefixed.NewSnapshot(ContractUID, snap)
+
switch Command(cmd) {
case CmdCreateForm:
err = c.cmd.createForm(snap, step)
diff --git a/contracts/evoting/mod_test.go b/contracts/evoting/mod_test.go
index adf46e2a4..f752ea62f 100644
--- a/contracts/evoting/mod_test.go
+++ b/contracts/evoting/mod_test.go
@@ -7,9 +7,9 @@ import (
"strconv"
"testing"
- "github.com/c4dt/d-voting/contracts/evoting/types"
- "github.com/c4dt/d-voting/internal/testing/fake"
- "github.com/c4dt/d-voting/services/dkg"
+ "github.com/dedis/d-voting/contracts/evoting/types"
+ "github.com/dedis/d-voting/internal/testing/fake"
+ "github.com/dedis/d-voting/services/dkg"
"github.com/prometheus/client_golang/prometheus/testutil"
"github.com/stretchr/testify/require"
"go.dedis.ch/dela/core/access"
diff --git a/deb-package/README.md b/deb-package/README.md
index 99e609bf1..a6222c9f3 100644
--- a/deb-package/README.md
+++ b/deb-package/README.md
@@ -198,7 +198,7 @@ sudo apt install rubygems build-essential git
## Get the code
```sh
-git clone https://github.com/c4dt/d-voting.git
+git clone https://github.com/dedis/d-voting.git
```
## Build the deb package
diff --git a/deb-package/build-deb.sh b/deb-package/build-deb.sh
index 0a61454ec..a374e11fa 100755
--- a/deb-package/build-deb.sh
+++ b/deb-package/build-deb.sh
@@ -45,7 +45,7 @@ fpm \
--after-install pkg/after-install.sh \
--before-remove pkg/before-remove.sh \
--after-remove pkg/after-remove.sh \
- --url https://dedis.github.com/c4dt/dvoting \
+ --url https://dedis.github.com/dedis/dvoting \
--description 'D-Voting package' \
--package dist .
diff --git a/docker-compose/docker-compose.debug.yml b/docker-compose/docker-compose.debug.yml
index 66a1ea7f5..642823d52 100644
--- a/docker-compose/docker-compose.debug.yml
+++ b/docker-compose/docker-compose.debug.yml
@@ -65,7 +65,7 @@ services:
ipv4_address: 172.19.44.251
frontend: # web service frontend
- image: ghcr.io/c4dt/d-voting-frontend:latest
+ image: ghcr.io/dedis/d-voting-frontend:latest
build:
dockerfile: Dockerfiles/Dockerfile.frontend
context: ../
@@ -83,7 +83,7 @@ services:
ipv4_address: 172.19.44.2
backend: # web service backend
- image: ghcr.io/c4dt/d-voting-backend:latest
+ image: ghcr.io/dedis/d-voting-backend:latest
build:
dockerfile: Dockerfiles/Dockerfile.backend
context: ../
diff --git a/docker-compose/docker-compose.yml b/docker-compose/docker-compose.yml
index 2e86e7634..88fd088e9 100644
--- a/docker-compose/docker-compose.yml
+++ b/docker-compose/docker-compose.yml
@@ -1,6 +1,6 @@
version: "3.8"
x-dela: &dela
- image: ghcr.io/c4dt/d-voting-dela:latest
+ image: ghcr.io/dedis/d-voting-dela:latest
env_file: ../.env
x-dela-env: &dela-env
PROXYKEY: ${PUBLIC_KEY}
@@ -55,7 +55,7 @@ services:
ipv4_address: 172.19.44.251
frontend: # web service frontend
- image: ghcr.io/c4dt/d-voting-frontend:latest
+ image: ghcr.io/dedis/d-voting-frontend:latest
build:
dockerfile: Dockerfiles/Dockerfile.frontend
context: ../
@@ -67,7 +67,7 @@ services:
ipv4_address: 172.19.44.2
backend: # web service backend
- image: ghcr.io/c4dt/d-voting-backend:latest
+ image: ghcr.io/dedis/d-voting-backend:latest
build:
dockerfile: Dockerfiles/Dockerfile.backend
context: ../
diff --git a/docs/coverpage.md b/docs/coverpage.md
index 4462113e3..df717a4c8 100644
--- a/docs/coverpage.md
+++ b/docs/coverpage.md
@@ -5,7 +5,7 @@
-
+
- An open platform to run voting instances on a blockchain
diff --git a/docs/index.html b/docs/index.html
index 4a414ee1a..1fd7617bc 100644
--- a/docs/index.html
+++ b/docs/index.html
@@ -13,7 +13,7 @@
diff --git a/contracts/evoting/types/election.go b/contracts/evoting/types/election.go
index bc2d41383..64db99b23 100644
--- a/contracts/evoting/types/election.go
+++ b/contracts/evoting/types/election.go
@@ -42,11 +42,11 @@ const (
Canceled Status = 6
)
// BallotsPerBlock to improve performance, so that (de)serializing only touches
// 100 ballots at a time.
-var BallotsPerBlock = uint32(100)
+var BallotsPerBatch = uint32(100)
-// TestCastBallots if true, automatically fills every block with ballots.
+// TestCastBallots if true, automatically fills every batch with ballots.
var TestCastBallots = false
// formFormat contains the supported formats for the form. Right now
@@ -78,18 +78,17 @@ type Form struct {
// to pad smaller ballots such that all ballots cast have the same size
BallotSize int
- // SuffragiaIDs holds a slice of IDs to slices of SuffragiaIDs.
+ // SuffragiaStoreKeys holds a slice of storage-keys to 0 or more Suffragia.
// This is to optimize the time it takes to (De)serialize a Form.
- SuffragiaIDs [][]byte
+ SuffragiaStoreKeys [][]byte
// BallotCount is the total number of ballots cast, including double
// ballots.
BallotCount uint32
// SuffragiaHashes holds a slice of hashes to all SuffragiaIDs.
// LG: not really sure if this is needed. In case a Form has also to be
// proven to be correct outside the nodes, the hashes are definitely
// needed.
SuffragiaHashes [][]byte
// ShuffleInstances is all the shuffles, along with their proof and identity
@@ -204,8 +203,9 @@ func (e *Form) ChunksPerBallot() int {
// CastVote stores the new vote in the memory.
func (s *Form) CastVote(ctx serde.Context, st store.Snapshot, userID string, ciphervote Ciphervote) error {
var suff Suffragia
- var blockID []byte
- if s.BallotCount%BallotsPerBlock == 0 {
+ var batchID []byte
+
+ if s.BallotCount%BallotsPerBatch == 0 {
// Need to create a random ID for storing the ballots.
// H( formID | ballotcount )
// should be random enough, even if it's previsible.
@@ -216,42 +216,43 @@ func (s *Form) CastVote(ctx serde.Context, st store.Snapshot, userID string, cip
h := sha256.New()
h.Write(id)
binary.LittleEndian.PutUint32(id, s.BallotCount)
- blockID = h.Sum(id[0:4])[:32]
- err = st.Set(blockID, []byte{})
+ batchID = h.Sum(id[0:4])[:32]
+
+ err = st.Set(batchID, []byte{})
if err != nil {
- return xerrors.Errorf("couldn't store new ballot block: %v", err)
+ return xerrors.Errorf("couldn't store new ballot batch: %v", err)
}
- s.SuffragiaIDs = append(s.SuffragiaIDs, blockID)
+ s.SuffragiaStoreKeys = append(s.SuffragiaStoreKeys, batchID)
s.SuffragiaHashes = append(s.SuffragiaHashes, []byte{})
} else {
- blockID = s.SuffragiaIDs[len(s.SuffragiaIDs)-1]
- buf, err := st.Get(blockID)
+ batchID = s.SuffragiaStoreKeys[len(s.SuffragiaStoreKeys)-1]
+ buf, err := st.Get(batchID)
if err != nil {
- return xerrors.Errorf("couldn't get ballots block: %v", err)
+ return xerrors.Errorf("couldn't get ballots batch: %v", err)
}
format := suffragiaFormat.Get(ctx.GetFormat())
ctx = serde.WithFactory(ctx, CiphervoteKey{}, CiphervoteFactory{})
msg, err := format.Decode(ctx, buf)
if err != nil {
- return xerrors.Errorf("couldn't unmarshal ballots block in cast: %v", err)
+ return xerrors.Errorf("couldn't unmarshal ballots batch in cast: %v", err)
}
suff = msg.(Suffragia)
}
suff.CastVote(userID, ciphervote)
if TestCastBallots {
- for i := uint32(1); i < BallotsPerBlock; i++ {
+ for i := uint32(1); i < BallotsPerBatch; i++ {
suff.CastVote(fmt.Sprintf("%s-%d", userID, i), ciphervote)
}
- s.BallotCount += BallotsPerBlock - 1
+ s.BallotCount += BallotsPerBatch - 1
}
buf, err := suff.Serialize(ctx)
if err != nil {
- return xerrors.Errorf("couldn't marshal ballots block: %v", err)
+ return xerrors.Errorf("couldn't marshal ballots batch: %v", err)
}
- err = st.Set(blockID, buf)
+ err = st.Set(batchID, buf)
if err != nil {
- xerrors.Errorf("couldn't set new ballots block: %v", err)
+ xerrors.Errorf("couldn't set new ballots batch: %v", err)
}
s.BallotCount += 1
return nil
@@ -263,16 +264,16 @@ func (s *Form) CastVote(ctx serde.Context, st store.Snapshot, userID string, cip
// the latest ballot.
func (s *Form) Suffragia(ctx serde.Context, rd store.Readable) (Suffragia, error) {
var suff Suffragia
- for _, id := range s.SuffragiaIDs {
+ for _, id := range s.SuffragiaStoreKeys {
buf, err := rd.Get(id)
if err != nil {
- return suff, xerrors.Errorf("couldn't get ballot block: %v", err)
+ return suff, xerrors.Errorf("couldn't get ballot batch: %v", err)
}
format := suffragiaFormat.Get(ctx.GetFormat())
ctx = serde.WithFactory(ctx, CiphervoteKey{}, CiphervoteFactory{})
msg, err := format.Decode(ctx, buf)
if err != nil {
- return suff, xerrors.Errorf("couldn't unmarshal ballots block in cast: %v", err)
+ return suff, xerrors.Errorf("couldn't unmarshal ballots batch in cast: %v", err)
}
suffTmp := msg.(Suffragia)
for i, uid := range suffTmp.UserIDs {
@@ -42,11 +42,11 @@ const (
Canceled Status = 6
)
-// BallotsPerBlock to improve performance, so that (de)serializing only touches
+// BallotsPerBatch to improve performance, so that (de)serializing only touches
// 100 ballots at a time.
@@ -78,18 +78,17 @@ type Form struct {
// ballots.
BallotCount uint32
- // SuffragiaHashes holds a slice of hashes to all SuffragiaIDs.
- // LG: not really sure if this is needed. In case a Form has also to be
- // proven to be correct outside the nodes, the hashes are definitely
- // needed.
+ // SuffragiaHashes holds a slice of hashes to all SuffragiaStoreKeys.
+ // In case a Form has also to be proven to be correct outside the nodes,
+ // the hashes are needed to prove the Suffragia are correct.
SuffragiaHashes [][]byte
// ShuffleInstances is all the shuffles, along with their proof and identity